@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.045';
+our $VERSION   = '0.046';
 
 use Types::Standard qw( Any Item );
 
@@ -50,4 +50,13 @@ sub _populate_cache {
 	\%hash;
 }
 
+sub expand_shortcut {
+	use Carp;
+	Carp::croak( "Not implemented" );
+}
+
+sub preprocess_spec {
+	return;
+}
+
 1;
